Class: Guard::PythonUnittest

Inherits:
Guard
  • Object
show all
Defined in:
lib/guard/python_unittest.rb

Instance Method Summary collapse

Constructor Details

#initialize(watchers = [], options = {}) ⇒ PythonUnittest

Initialize a Guard.

Parameters:

  • watchers (Array<Guard::Watcher>) (defaults to: [])

    the Guard file watchers

  • options (Hash) (defaults to: {})

    the custom Guard options



9
10
11
12
13
14
# File 'lib/guard/python_unittest.rb', line 9

def initialize(watchers = [], options = {})
  watchers << test_file_watcher
  watchers << implementation_file_watcher

  super(watchers, options)
end

Instance Method Details

#run_allObject

Called when just enter is pressed This method should be principally used for long action like running all specs/tests/…

Raises:

  • (:task_has_failed)

    when run_all has failed



23
24
25
# File 'lib/guard/python_unittest.rb', line 23

def run_all
  run_tests_and_report
end

#run_on_changes(paths) ⇒ Object

Called on file(s) modifications that the Guard watches.

Parameters:

  • paths (Array<String>)

    the changes files or paths

Raises:

  • (:task_has_failed)

    when run_on_change has failed



30
31
32
# File 'lib/guard/python_unittest.rb', line 30

def run_on_changes(paths)
  run_tests_and_report(paths)
end

#startObject



16
17
18
# File 'lib/guard/python_unittest.rb', line 16

def start
  run_all
end