Class: Guard::PythonUnittest
- Inherits:
-
Guard
- Object
- Guard
- Guard::PythonUnittest
- Defined in:
- lib/guard/python_unittest.rb
Instance Method Summary collapse
-
#initialize(watchers = [], options = {}) ⇒ PythonUnittest
constructor
Initialize a Guard.
-
#run_all ⇒ Object
Called when just
enteris pressed This method should be principally used for long action like running all specs/tests/… -
#run_on_changes(paths) ⇒ Object
Called on file(s) modifications that the Guard watches.
- #start ⇒ Object
Constructor Details
#initialize(watchers = [], options = {}) ⇒ PythonUnittest
Initialize a Guard.
9 10 11 12 13 14 |
# File 'lib/guard/python_unittest.rb', line 9 def initialize(watchers = [], = {}) watchers << test_file_watcher watchers << implementation_file_watcher super(watchers, ) end |
Instance Method Details
#run_all ⇒ Object
Called when just enter is pressed This method should be principally used for long action like running all specs/tests/…
23 24 25 |
# File 'lib/guard/python_unittest.rb', line 23 def run_all run_tests_and_report end |
#run_on_changes(paths) ⇒ Object
Called on file(s) modifications that the Guard watches.
30 31 32 |
# File 'lib/guard/python_unittest.rb', line 30 def run_on_changes(paths) run_tests_and_report(paths) end |
#start ⇒ Object
16 17 18 |
# File 'lib/guard/python_unittest.rb', line 16 def start run_all end |